import React, { useRef } from 'react';

function useInterval(callback, delay) {
  var savedCallback = useRef(); // Remember the latest callback.

  React.useEffect(function () {
    savedCallback.current = callback;
  }, [callback]); // Set up the interval.

  React.useEffect(function () {
    function tick() {
      if (typeof savedCallback.current === 'function') {
        savedCallback.current();
      }
    }

    if (delay !== null) {
      var id = setInterval(tick, delay);
      return function () {
        return clearInterval(id);
      };
    }
  }, [delay]);
}

function useTypingEffect(_ref) {
  var over = _ref.over,
      _ref$charSpeed = _ref.charSpeed,
      charSpeed = _ref$charSpeed === void 0 ? 100 : _ref$charSpeed,
      _ref$loop = _ref.loop,
      loop = _ref$loop === void 0 ? true : _ref$loop,
      _ref$delayEnd = _ref.delayEnd,
      delayEnd = _ref$delayEnd === void 0 ? 500 : _ref$delayEnd;
  var savedMessage = React.useRef(['']);
  var inWordIndex = React.useRef(0);
  var inArrayIndex = React.useRef(0);
  React.useEffect(function () {
    if (typeof over === 'string') {
      savedMessage.current = [over];
    } else if (Array.isArray(over)) {
      savedMessage.current = over.map(function (el) {
        return el.toString();
      });
    }
  }, [over]);

  var _React$useState = React.useState(savedMessage.current ? savedMessage.current[inArrayIndex.current][inWordIndex.current] : ''),
      display = _React$useState[0],
      setDisplay = _React$useState[1]; //Go to next


  useInterval(function () {
    if (inWordIndex.current <= savedMessage.current[inArrayIndex.current].length + delayEnd / charSpeed) {
      inWordIndex.current = inWordIndex.current + 1;
      setDisplay(savedMessage.current[inArrayIndex.current].slice(0, inWordIndex.current));
    } else {
      //Current word is finished
      if (inArrayIndex.current < savedMessage.current.length - 1) {
        inArrayIndex.current = inArrayIndex.current + 1;
      } else if (loop) {
        inArrayIndex.current = 0;
      }

      inWordIndex.current = 0;
    }
  }, charSpeed);
  return display;
}

export default useTypingEffect;
//# sourceMappingURL=react-use-typing-effect.esm.js.map
